=================================
Generate pages with scalar tables
=================================

.. automodule:: abed.html.scalar_tables
    :members:
    :undoc-members:
    :show-inheritance:
